from interfaces import IAdding, IFactoryAdding
from interfaces import IFieldsCustomization, IObjectInitializedEvent
from events import ObjectInitializedEvent
from addview import Adder
from crudforms import Display, Add, Edit, Delete
from customize import FieldsCustomizer
